@@ -348,6 +348,23 @@ exampleRFA01 <- function () {
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 # ------------------------------------------------------------------------------------------- #
 
 
@@ -804,25 +821,45 @@ exampleRFA02 <- function () {
 
   cat("\n
   > par1 <- par.gamma(Lmom.1[\"l1\"],Lmom.1[\"l2\"],Lmom.1[\"lca\"])
-  > mom2par.gamma(par1$mu,par1$sigma,par1$gamm)
+  > par1
   \n")
 
   par1 <- par.gamma(Lmom.1["l1"],Lmom.1["l2"],Lmom.1["lca"]);
-  print(mom2par.gamma(par1$mu,par1$sigma,par1$gamm))
+  print(par1)
 
   cat("\n
-  > F1 <- F.gamma(D15.1adim,par1$mu,par1$sigma,par1$gamm)
+  > F1 <- F.gamma(D15.1adim,par1$xi,par1$beta,par1$alfa)
   > regionalplotpos(D15.1adim,cod15.1,xlab=\"cluster1\",main=\"Empirical distributions\",cex.main=1,font.main=1)
   > lines(sort(D15.1adim),sort(F1))
   > AD <- gofP3test(D15.1adim,Nsim=100)
-  > mtext(paste(\"P(AD) = \",round(AD[2],3)),3,-1.5,adj=0.05)
+  > ADb <- A2_GOFlaio(D15.1adim, dist=\"GAM\")
+  > AD2 <- gofGEVtest(D15.1adim,Nsim=100)
+  > AD2b <- A2_GOFlaio(D15.1adim, dist=\"GEV\")
+  > AD3 <- gofGENLOGIStest(D15.1adim,Nsim=100)
+  > AD4 <- gofGENPARtest(D15.1adim,Nsim=100)
+  > AD5 <- gofLOGNORMtest(D15.1adim,Nsim=100)
+  > mtext(paste(\"P(AD) P3 = \",round(AD[2],3),\", \",round(ADb[2],3)),3,-1.5,adj=0.05)
+  > mtext(paste(\"P(AD) GEV = \",round(AD2[2],3),\", \",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  > mtext(paste(\"P(AD) GL = \",round(AD3[2],3)),3,-3.5,adj=0.05)
+  > mtext(paste(\"P(AD) GP = \",round(AD4[2],3)),3,-4.5,adj=0.05)
+  > mtext(paste(\"P(AD) LN = \",round(AD5[2],3)),3,-5.5,adj=0.05)
   \n")
 
-  F1 <- F.gamma(D15.1adim,par1$mu,par1$sigma,par1$gamm)
+  F1 <- F.gamma(D15.1adim,par1$xi,par1$beta,par1$alfa)
   regionalplotpos(D15.1adim,cod15.1,xlab="cluster1",main="Empirical distributions",cex.main=1,font.main=1)
   lines(sort(D15.1adim),sort(F1))
   AD <- gofP3test(D15.1adim,Nsim=100)
-  mtext(paste("P(AD) = ",round(AD[2],3)),3,-1.5,adj=0.05)
+  ADb <- A2_GOFlaio(D15.1adim, dist="GAM")
+  AD2 <- gofGEVtest(D15.1adim,Nsim=100)
+  AD2b <- A2_GOFlaio(D15.1adim, dist="GEV")
+  AD3 <- gofGENLOGIStest(D15.1adim,Nsim=100)
+  AD4 <- gofGENPARtest(D15.1adim,Nsim=100)
+  AD5 <- gofLOGNORMtest(D15.1adim,Nsim=100)
+  mtext(paste("P(AD) P3 = ",round(AD[2],3),", ",round(ADb[2],3)),3,-1.5,adj=0.05)
+  mtext(paste("P(AD) GEV = ",round(AD2[2],3),", ",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  mtext(paste("P(AD) GL = ",round(AD3[2],3)),3,-3.5,adj=0.05)
+  mtext(paste("P(AD) GP = ",round(AD4[2],3)),3,-4.5,adj=0.05)
+  mtext(paste("P(AD) LN = ",round(AD5[2],3)),3,-5.5,adj=0.05)
 
   readline("\n
   # ------------------------------------------------------------------------------------- #\n
@@ -838,25 +875,45 @@ exampleRFA02 <- function () {
 
   cat("\n
   > par2 <- par.gamma(Lmom.2[\"l1\"],Lmom.2[\"l2\"],Lmom.2[\"lca\"])
-  > mom2par.gamma(par2$mu,par2$sigma,par2$gamm)
+  > par2
   \n")
 
   par2 <- par.gamma(Lmom.2["l1"],Lmom.2["l2"],Lmom.2["lca"])
-  print(mom2par.gamma(par2$mu,par2$sigma,par2$gamm))
+  print(par2)
 
   cat("\n
-  > F2 <- F.gamma(D15.2adim,par2$mu,par2$sigma,par2$gamm)
+  > F2 <- F.gamma(D15.2adim,par2$xi,par2$beta,par2$alfa)
   > regionalplotpos(D15.2adim,cod15.2,xlab=\"cluster2\",main=\"Empirical distributions\",cex.main=1,font.main=1)
   > lines(sort(D15.2adim),sort(F2))
-  > AD <- gofP3test(D15.2adim,Nsim=100); AD
-  > mtext(paste(\"P(AD) = \",round(AD[2],3)),3,-1.5,adj=0.05)
+  > AD <- gofP3test(D15.2adim,Nsim=100)
+  > ADb <- A2_GOFlaio(D15.2adim, dist=\"GAM\")
+  > AD2 <- gofGEVtest(D15.2adim,Nsim=100)
+  > AD2b <- A2_GOFlaio(D15.2adim, dist=\"GEV\")
+  > AD3 <- gofGENLOGIStest(D15.2adim,Nsim=100)
+  > AD4 <- gofGENPARtest(D15.2adim,Nsim=100)
+  > AD5 <- gofLOGNORMtest(D15.2adim,Nsim=100)
+  > mtext(paste(\"P(AD) P3 = \",round(AD[2],3),\", \",round(ADb[2],3)),3,-1.5,adj=0.05)
+  > mtext(paste(\"P(AD) GEV = \",round(AD2[2],3),\", \",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  > mtext(paste(\"P(AD) GL = \",round(AD3[2],3)),3,-3.5,adj=0.05)
+  > mtext(paste(\"P(AD) GP = \",round(AD4[2],3)),3,-4.5,adj=0.05)
+  > mtext(paste(\"P(AD) LN = \",round(AD5[2],3)),3,-5.5,adj=0.05)
   \n")
 
-  F2 <- F.gamma(D15.2adim,par2$mu,par2$sigma,par2$gamm)
+  F2 <- F.gamma(D15.2adim,par2$xi,par2$beta,par2$alfa)
   regionalplotpos(D15.2adim,cod15.2,xlab="cluster2",main="Empirical distributions",cex.main=1,font.main=1)
   lines(sort(D15.2adim),sort(F2))
-  AD <- gofP3test(D15.2adim,Nsim=100); AD
-  mtext(paste("P(AD) = ",round(AD[2],3)),3,-1.5,adj=0.05)
+  AD <- gofP3test(D15.2adim,Nsim=100)
+  ADb <- A2_GOFlaio(D15.2adim, dist="GAM")
+  AD2 <- gofGEVtest(D15.2adim,Nsim=100)
+  AD2b <- A2_GOFlaio(D15.2adim, dist="GEV")
+  AD3 <- gofGENLOGIStest(D15.2adim,Nsim=100)
+  AD4 <- gofGENPARtest(D15.2adim,Nsim=100)
+  AD5 <- gofLOGNORMtest(D15.2adim,Nsim=100)
+  mtext(paste("P(AD) P3 = ",round(AD[2],3),", ",round(ADb[2],3)),3,-1.5,adj=0.05)
+  mtext(paste("P(AD) GEV = ",round(AD2[2],3),", ",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  mtext(paste("P(AD) GL = ",round(AD3[2],3)),3,-3.5,adj=0.05)
+  mtext(paste("P(AD) GP = ",round(AD4[2],3)),3,-4.5,adj=0.05)
+  mtext(paste("P(AD) LN = ",round(AD5[2],3)),3,-5.5,adj=0.05)
 
   readline("\n
   # ------------------------------------------------------------------------------------- #\n
@@ -872,25 +929,45 @@ exampleRFA02 <- function () {
 
   cat("\n
   > par3 <- par.gamma(Lmom.3[\"l1\"],Lmom.3[\"l2\"],Lmom.3[\"lca\"])
-  > mom2par.gamma(par3$mu,par3$sigma,par3$gamm)
+  > par3
   \n")
 
   par3 <- par.gamma(Lmom.3["l1"],Lmom.3["l2"],Lmom.3["lca"])
-  print(mom2par.gamma(par3$mu,par3$sigma,par3$gamm))
+  print(par3)
 
   cat("\n
-  > F3 <- F.gamma(D15.3adim,par3$mu,par3$sigma,par3$gamm)
+  > F3 <- F.gamma(D15.3adim,par3$xi,par3$beta,par3$alfa)
   > regionalplotpos(D15.3adim,cod15.3,xlab=\"cluster3\",main=\"Empirical distributions\",cex.main=1,font.main=1)
   > lines(sort(D15.3adim),sort(F3))
-  > AD <- gofP3test(D15.3adim,Nsim=100); AD
-  > mtext(paste(\"P(AD) = \",round(AD[2],3)),3,-1.5,adj=0.05)
+  > AD <- gofP3test(D15.3adim,Nsim=100)
+  > ADb <- A2_GOFlaio(D15.3adim, dist=\"GAM\")
+  > AD2 <- gofGEVtest(D15.3adim,Nsim=100)
+  > AD2b <- A2_GOFlaio(D15.3adim, dist=\"GEV\")
+  > AD3 <- gofGENLOGIStest(D15.3adim,Nsim=100)
+  > AD4 <- gofGENPARtest(D15.3adim,Nsim=100)
+  > AD5 <- gofLOGNORMtest(D15.3adim,Nsim=100)
+  > mtext(paste(\"P(AD) P3 = \",round(AD[2],3),\", \",round(ADb[2],3)),3,-1.5,adj=0.05)
+  > mtext(paste(\"P(AD) GEV = \",round(AD2[2],3),\", \",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  > mtext(paste(\"P(AD) GL = \",round(AD3[2],3)),3,-3.5,adj=0.05)
+  > mtext(paste(\"P(AD) GP = \",round(AD4[2],3)),3,-4.5,adj=0.05)
+  > mtext(paste(\"P(AD) LN = \",round(AD5[2],3)),3,-5.5,adj=0.05)
   \n")
 
-  F3 <- F.gamma(D15.3adim,par3$mu,par3$sigma,par3$gamm)
+  F3 <- F.gamma(D15.3adim,par3$xi,par3$beta,par3$alfa)
   regionalplotpos(D15.3adim,cod15.3,xlab="cluster3",main="Empirical distributions",cex.main=1,font.main=1)
   lines(sort(D15.3adim),sort(F3))
-  AD <- gofP3test(D15.3adim,Nsim=100); AD
-  mtext(paste("P(AD) = ",round(AD[2],3)),3,-1.5,adj=0.05)
+  AD <- gofP3test(D15.3adim,Nsim=100)
+  ADb <- A2_GOFlaio(D15.3adim, dist="GAM")
+  AD2 <- gofGEVtest(D15.3adim,Nsim=100)
+  AD2b <- A2_GOFlaio(D15.3adim, dist="GEV")
+  AD3 <- gofGENLOGIStest(D15.3adim,Nsim=100)
+  AD4 <- gofGENPARtest(D15.3adim,Nsim=100)
+  AD5 <- gofLOGNORMtest(D15.3adim,Nsim=100)
+  mtext(paste("P(AD) P3 = ",round(AD[2],3),", ",round(ADb[2],3)),3,-1.5,adj=0.05)
+  mtext(paste("P(AD) GEV = ",round(AD2[2],3),", ",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  mtext(paste("P(AD) GL = ",round(AD3[2],3)),3,-3.5,adj=0.05)
+  mtext(paste("P(AD) GP = ",round(AD4[2],3)),3,-4.5,adj=0.05)
+  mtext(paste("P(AD) LN = ",round(AD5[2],3)),3,-5.5,adj=0.05)
 
   readline("\n
   # ------------------------------------------------------------------------------------- #\n
@@ -906,25 +983,46 @@ exampleRFA02 <- function () {
 
   cat("\n
   > par4 <- par.gamma(Lmom.4[\"l1\"],Lmom.4[\"l2\"],Lmom.4[\"lca\"])
-  > mom2par.gamma(par4$mu,par4$sigma,par4$gamm)
+  > par4
   \n")
 
   par4 <- par.gamma(Lmom.4["l1"],Lmom.4["l2"],Lmom.4["lca"])
-  print(mom2par.gamma(par4$mu,par4$sigma,par4$gamm))
+  print(par4)
 
   cat("\n
-  > F4 <- F.gamma(D15.4adim,par4$mu,par4$sigma,par4$gamm)
+  > F4 <- F.gamma(D15.4adim,par4$xi,par4$beta,par4$alfa)
   > regionalplotpos(D15.4adim,cod15.4,xlab=\"cluster4\",main=\"Empirical distributions\",cex.main=1,font.main=1)
   > lines(sort(D15.4adim),sort(F4))
-  > AD <- gofP3test(D15.4adim,Nsim=100); AD
-  > mtext(paste(\"P(AD) = \",round(AD[2],3)),3,-1.5,adj=0.05)
+  > AD <- gofP3test(D15.4adim,Nsim=100)
+  > ADb <- A2_GOFlaio(D15.4adim, dist=\"GAM\")
+  > AD2 <- gofGEVtest(D15.4adim,Nsim=100)
+  > AD2b <- A2_GOFlaio(D15.4adim, dist=\"GEV\")
+  > AD3 <- gofGENLOGIStest(D15.4adim,Nsim=100)
+  > AD4 <- gofGENPARtest(D15.4adim,Nsim=100)
+  > AD5 <- gofLOGNORMtest(D15.4adim,Nsim=100)
+  > mtext(paste(\"P(AD) P3 = \",round(AD[2],3),\", \",round(ADb[2],3)),3,-1.5,adj=0.05)
+  > mtext(paste(\"P(AD) GEV = \",round(AD2[2],3),\", \",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  > mtext(paste(\"P(AD) GL = \",round(AD3[2],3)),3,-3.5,adj=0.05)
+  > mtext(paste(\"P(AD) GP = \",round(AD4[2],3)),3,-4.5,adj=0.05)
+  > mtext(paste(\"P(AD) LN = \",round(AD5[2],3)),3,-5.5,adj=0.05)
   \n")
 
-  F4 <- F.gamma(D15.4adim,par4$mu,par4$sigma,par4$gamm)
+  F4 <- F.gamma(D15.4adim,par4$xi,par4$beta,par4$alfa)
   regionalplotpos(D15.4adim,cod15.4,xlab="cluster4",main="Empirical distributions",cex.main=1,font.main=1)
   lines(sort(D15.4adim),sort(F4))
-  AD <- gofP3test(D15.4adim,Nsim=100); AD
-  mtext(paste("P(AD) = ",round(AD[2],3)),3,-1.5,adj=0.05)
+  AD <- gofP3test(D15.4adim,Nsim=100)
+  ADb <- A2_GOFlaio(D15.4adim, dist="GAM")
+  AD2 <- gofGEVtest(D15.4adim,Nsim=100)
+  AD2b <- A2_GOFlaio(D15.4adim, dist="GEV")
+  AD3 <- gofGENLOGIStest(D15.4adim,Nsim=100)
+  AD4 <- gofGENPARtest(D15.4adim,Nsim=100)
+  AD5 <- gofLOGNORMtest(D15.4adim,Nsim=100)
+  mtext(paste("P(AD) P3 = ",round(AD[2],3),", ",round(ADb[2],3)),3,-1.5,adj=0.05)
+  mtext(paste("P(AD) GEV = ",round(AD2[2],3),", ",round(AD2b[2],3)),3,-2.5,adj=0.05)
+  mtext(paste("P(AD) GL = ",round(AD3[2],3)),3,-3.5,adj=0.05)
+  mtext(paste("P(AD) GP = ",round(AD4[2],3)),3,-4.5,adj=0.05)
+  mtext(paste("P(AD) LN = ",round(AD5[2],3)),3,-5.5,adj=0.05)
+
 
   readline("\n
   # ------------------------------------------------------------------------------------- #\n
@@ -934,10 +1032,10 @@ exampleRFA02 <- function () {
   cat("\n
   Comparison between regional growth-curves:
   > Fs <- seq(0.001,0.999,by=.001)
-  > q1 <- invF.gamma(Fs,par1$mu,par1$sigma,par1$gamm)
-  > q2 <- invF.gamma(Fs,par2$mu,par2$sigma,par2$gamm)
-  > q3 <- invF.gamma(Fs,par3$mu,par3$sigma,par3$gamm)
-  > q4 <- invF.gamma(Fs,par4$mu,par4$sigma,par4$gamm)
+  > q1 <- invF.gamma(Fs,par1$xi,par1$beta,par1$alfa)
+  > q2 <- invF.gamma(Fs,par2$xi,par2$beta,par2$alfa)
+  > q3 <- invF.gamma(Fs,par3$xi,par3$beta,par3$alfa)
+  > q4 <- invF.gamma(Fs,par4$xi,par4$beta,par4$alfa)
 
   > lognormplot(c(q1,q2,q3,q4),line=FALSE,type=\"n\")
   > normpoints(q1,type=\"l\",lty=1,col=1)
@@ -948,10 +1046,10 @@ exampleRFA02 <- function () {
   \n")
 
   Fs <- seq(0.001,0.999,by=.001)
-  q1 <- invF.gamma(Fs,par1$mu,par1$sigma,par1$gamm)
-  q2 <- invF.gamma(Fs,par2$mu,par2$sigma,par2$gamm)
-  q3 <- invF.gamma(Fs,par3$mu,par3$sigma,par3$gamm)
-  q4 <- invF.gamma(Fs,par4$mu,par4$sigma,par4$gamm)
+  q1 <- invF.gamma(Fs,par1$xi,par1$beta,par1$alfa)
+  q2 <- invF.gamma(Fs,par2$xi,par2$beta,par2$alfa)
+  q3 <- invF.gamma(Fs,par3$xi,par3$beta,par3$alfa)
+  q4 <- invF.gamma(Fs,par4$xi,par4$beta,par4$alfa)
 
   lognormplot(c(q1,q2,q3,q4),line=FALSE,type="n")
   normpoints(q1,type="l",lty=1,col=1)
@@ -960,6 +1058,183 @@ exampleRFA02 <- function () {
   normpoints(q4,type="l",lty=4,col=4)
   legend("bottomright",paste("cluster ",c(1:4)),col=c(1:4),lty=c(1:4),bty="n")
 
+
+  readline("\n
+  # ------------------------------------------------------------------------------------- #\n
+  Press Return to continue
+  \n")
+
+  cat("\n
+  Final tests of goodness-of-fit. 
+  
+  The regionalized distribution adaptation, with mean 
+    D.est = exp(7.86 + 0.000291*Hm + 0.0722*NORD - 1.70*IB)
+  and parameters of Pearson type III distribution
+    xi1 = 0.5458;  beta1 = 0.09534; alfa1 = 4.764;
+    xi2 = 0.09843; beta2 = 0.08508; alfa2 = 10.60;
+    xi3 = 0.2801;  beta3 = 0.1237;  alfa3 = 5.817;
+    xi4 = 0.3496;  beta4 = 0.2093;  alfa4 = 3.107
+  is tested throught the Anderson-Darling and the Cramer-von Mises
+  goodness-of-fit tests.
+  In this case (fully specified distribution) the percentage points
+  are:
+         .25    .10    .05    .01   .001
+    A2 1.248  1.933  2.492  3.880  6.000
+    W2 0.209  0.347  0.461  0.743  1.167  \n
+
+  > A2fullspecif <- function (x,xi,beta,alfa) {
+  >  x <- sort(x)
+  >  n <- length(x)
+  >  F <- pgamma((x - xi)/beta, alfa)
+  >  F[F<=0] <- 0.000001
+  >  F[F>=1] <- 0.999999
+  >  -n-(1/n)*sum((seq(1,2*n-1,by=2))*log(F) + (seq(2*n-1,1,by=-2))*log(1-F))
+  > }
+  > W2fullspecif <- function (x,xi,beta,alfa) {
+  >  x <- sort(x)
+  >  n <- length(x)
+  >  F <- pgamma((x - xi)/beta, alfa)
+  >  sum((F - seq(1,2*n-1,by=2)/(2*n))^2) + 1/(12*n)
+  > }
+  > par(mfrow=c(3,2))
+  > W2s <- rep(NA,47)
+  > A2s <- rep(NA,47)
+  > em <- rep(NA,47)
+  > gruppi <- rep(NA,47)
+  > ferma=6
+  > for(i in 1:47) {
+  >  codice <- unique(cod)[i]
+  >  Hm <- parameters[parameters[\"cod\"]==codice,\"Hm\"]
+  >  NORD <- parameters[parameters[\"cod\"]==codice,\"NORD\"]
+  >  IB <- parameters[parameters[\"cod\"]==codice,\"IB\"]
+  >  Ybar <- parameters[parameters[\"cod\"]==codice,\"Ybar\"]
+  >  baricentri.clusterD <- cbind(c(2327.455,1404.200,1892.214,812.125),c(45.77200,46.01480,44.58071,44.47513))
+  >  baricentri.clusterD[,1] <- (baricentri.clusterD[,1]-1694)/652.1
+  >  baricentri.clusterD[,2] <- (baricentri.clusterD[,2]-45.12)/0.7229
+  >  HmYbar <- c((Hm-1694)/652.1,(Ybar-45.12)/0.7229)
+  >  distanze <- as.matrix(dist(rbind(HmYbar,baricentri.clusterD)))[-1,1]
+  >  gruppo <- which.min(distanze)
+  >  em[i] <- exp(7.86 + 0.000291*Hm + 0.0722*NORD - 1.70*IB)
+  >  if(gruppo==1){
+  >   xi=0.5458; beta=0.09534; alfa=4.764;
+  >  }
+  >  else if(gruppo==2){
+  >   xi=0.09843; beta=0.08508; alfa=10.60;
+  >  }
+  >  else if(gruppo==3){
+  >   xi=0.2801; beta=0.1237; alfa=5.817;
+  >  }
+  >  else if(gruppo==4){
+  >   xi=0.3496; beta=0.2093; alfa=3.107;
+  >  }
+  >  gruppi[i] <- gruppo
+  >  campione <- annualflows[annualflows[\"cod\"]==codice,3]
+  >  plotpos(campione,main=row.names(parameters[parameters[\"cod\"]==codice,]),cex.main=1,font.main=1)
+  >  lines(sort(campione),pgamma((sort(campione)-em[i]*xi)/(em[i]*beta),alfa))
+  >  A2s[i] <- A2fullspecif(campione,em[i]*xi,em[i]*beta,alfa)
+  >  W2s[i] <- W2fullspecif(campione,em[i]*xi,em[i]*beta,alfa)
+  >  mtext(paste(\"A2 = \",round(A2s[i],3)),3,-1.5,adj=0.05)
+  >  mtext(paste(\"W2 = \",round(W2s[i],3)),1,-1.5,adj=0.95)
+  >  if(i==ferma) {
+  >   ferma <- ferma+6
+  >   readline(\"Press Return to continue to the next graphs\")
+  >  }
+  > }
+  > tabella <- cbind(parameters[1:2],round(em),gruppi,A2s,W2s)
+  > tabella
+  > par(mfrow=c(1,1))
+  \n")
+
+  A2fullspecif <- function (x,xi,beta,alfa) {
+   x <- sort(x)
+   n <- length(x)
+   F <- pgamma((x - xi)/beta, alfa)
+   F[F<=0] <- 0.000001
+   F[F>=1] <- 0.999999
+   -n-(1/n)*sum((seq(1,2*n-1,by=2))*log(F) + (seq(2*n-1,1,by=-2))*log(1-F))
+  } 
+  W2fullspecif <- function (x,xi,beta,alfa) {
+   x <- sort(x)
+   n <- length(x)
+   F <- pgamma((x - xi)/beta, alfa)
+   sum((F - seq(1,2*n-1,by=2)/(2*n))^2) + 1/(12*n)
+  }
+  par(mfrow=c(3,2))
+  W2s <- rep(NA,47)
+  A2s <- rep(NA,47)
+  em <- rep(NA,47)
+  gruppi <- rep(NA,47)
+  ferma=6
+  for(i in 1:47) {
+   codice <- unique(cod)[i]
+   Hm <- parameters[parameters["cod"]==codice,"Hm"]
+   NORD <- parameters[parameters["cod"]==codice,"NORD"]
+   IB <- parameters[parameters["cod"]==codice,"IB"]
+   Ybar <- parameters[parameters["cod"]==codice,"Ybar"]
+   baricentri.clusterD <- cbind(c(2327.455,1404.200,1892.214,812.125),c(45.77200,46.01480,44.58071,44.47513))
+   baricentri.clusterD[,1] <- (baricentri.clusterD[,1]-1694)/652.1
+   baricentri.clusterD[,2] <- (baricentri.clusterD[,2]-45.12)/0.7229
+   HmYbar <- c((Hm-1694)/652.1,(Ybar-45.12)/0.7229)
+   distanze <- as.matrix(dist(rbind(HmYbar,baricentri.clusterD)))[-1,1]
+   gruppo <- which.min(distanze)
+   em[i] <- exp(7.86 + 0.000291*Hm + 0.0722*NORD - 1.70*IB)
+   if(gruppo==1){
+    xi=0.5458; beta=0.09534; alfa=4.764;
+   }
+   else if(gruppo==2){
+    xi=0.09843; beta=0.08508; alfa=10.60;
+   }
+   else if(gruppo==3){
+    xi=0.2801; beta=0.1237; alfa=5.817;
+   }
+   else if(gruppo==4){
+    xi=0.3496; beta=0.2093; alfa=3.107;
+   }
+   gruppi[i] <- gruppo
+   campione <- annualflows[annualflows["cod"]==codice,3]
+   plotpos(campione,main=row.names(parameters[parameters["cod"]==codice,]),cex.main=1,font.main=1)
+   lines(sort(campione),pgamma((sort(campione)-em[i]*xi)/(em[i]*beta),alfa))
+   A2s[i] <- A2fullspecif(campione,em[i]*xi,em[i]*beta,alfa)
+   W2s[i] <- W2fullspecif(campione,em[i]*xi,em[i]*beta,alfa)
+   mtext(paste("A2 = ",round(A2s[i],3)),3,-1.5,adj=0.05) 
+   mtext(paste("W2 = ",round(W2s[i],3)),1,-1.5,adj=0.95)
+   if(i==ferma) {
+    ferma <- ferma+6
+    readline("Press Return to continue to the next graphs")
+   }
+  }
+  #tabella <- cbind(parameters[1],round(tapply(D,cod,mean)),round(em),gruppi,A2s,W2s)
+  tabella <- cbind(parameters[1:2],round(em),gruppi,A2s,W2s)
+  names(tabella) <- c("cod","tildeDm","hatDm","group","A2","W2")
+  print(tabella) 
+  par(mfrow=c(1,1))
+
+  readline("\n
+  # ------------------------------------------------------------------------------------- #\n
+  Press Return to continue
+  \n")
+
+  cat("\n
+  Dependency on the estimation of the mean.
+  > errors <- abs((tabella[,2] - tabella[,3])/tabella[,2])
+  > codici <- tabella[,1]
+  > plot(A2s,errors,main=\"\",xlab=expression(A^2),ylab=expression(paste(\"|(\",hat(D)[m] - tilde(D)[m],\")/\",tilde(D)[m],\"|\")))
+  > grid()
+  > abline(v=2.492,lty=2,col=2)
+  > abline(v=3.880,lty=2,col=2)
+  > text(A2s[A2s>3.880],errors[A2s>3.880],labels=codici[A2s>3.880]-2,pos=1)
+  > axis(1,at=c(2.492,3.880),labels=c(\"5\%\",\"1\%\"),col=2,col.axis=2,cex.axis=.8)
+  \n")
+
+  errors <- abs((tabella[,2] - tabella[,3])/tabella[,2])
+  codici <- tabella[,1]
+  plot(A2s,errors,main="",xlab=expression(A^2),ylab=expression(paste("|(",hat(D)[m] - tilde(D)[m],")/",tilde(D)[m],"|")))
+  grid()
+  abline(v=2.492,lty=2,col=2)
+  abline(v=3.880,lty=2,col=2)
+  text(A2s[A2s>3.880],errors[A2s>3.880],labels=codici[A2s>3.880]-2,pos=1)
+  axis(1,at=c(2.492,3.880),labels=c("5\%","1\%"),col=2,col.axis=2,cex.axis=.8)
+
   cat("\n\n
   # ------------------------------------------------------------------------------------- #
   # ------------------------------------------------------------------------------------- #
